__version__ = "1.0"

__author__ = "Daniil Tikhonov"

DEFAULT_BOT_FOLDER = "irispy_bot"

errors = {
    1: {"response": "error", "error_code": 1},
    2: {"response": "error", "error_code": 2},
    3: {"response": "error", "error_code": 3},
    4: {"response": "error", "error_code": 4},
    5: {"response": "error", "error_code": 10}
}

prefixes = [".д", ".с", "!дежурный", "!сигнал"]